Plot ROC curves for individual and ensemble models in a caret_stack
Source:R/caret_stack.R
plot_roc.caret_stack.RdThis function calculates ROC curves for all base models and the ensemble model
using the out-of-fold predictions from a caret_stack object.
The pROC package is used to compute the ROC curves. ROC curves can only be constructed for binary calssifiers.
Usage
# S3 method for class 'caret_stack'
plot_roc(object, include_auc = TRUE, ...)